@@ -627,6 +627,16 @@ class IP:
                     is_installed = False
                     break
         return is_installed
+    
+    def delete_dependencies(self):
+        for dep in self.dependencies:
+            dep_ip = get_ip(dep.vendor, dep.target_ip)
+            if dep_ip != None:
+                if not dep_ip.is_local:
+                    dep_ip.delete_local_files()
+    
+    def delete_local_files(self):
+        common.remove_dir(self.path)
 
 
 def get_key(obj):
