@@ -47,11 +47,11 @@ def main(ip_str, deep_clean):
 
 def clean_core(core):
     common.info(f"Deleting code and compiled code objects for FuseSoC core '{core.sname}'")
-    common.remove_dir(cfg.sim_output_dir + '/viv/cmp_wd/@fsoc__' + core.sname)
-    common.remove_dir(cfg.sim_output_dir + '/vcs/cmp_wd/@fsoc__' + core.sname)
-    common.remove_dir(cfg.sim_output_dir + '/xcl/cmp_wd/@fsoc__' + core.sname)
-    common.remove_dir(cfg.sim_output_dir + '/qst/cmp_wd/@fsoc__' + core.sname)
-    common.remove_dir(cfg.sim_output_dir + '/riv/cmp_wd/@fsoc__' + core.sname)
+    common.remove_dir(cfg.sim_output_dir + '/viv/sim_wd/@fsoc__' + core.sname)
+    common.remove_dir(cfg.sim_output_dir + '/vcs/sim_wd/@fsoc__' + core.sname)
+    common.remove_dir(cfg.sim_output_dir + '/xcl/sim_wd/@fsoc__' + core.sname)
+    common.remove_dir(cfg.sim_output_dir + '/qst/sim_wd/@fsoc__' + core.sname)
+    common.remove_dir(cfg.sim_output_dir + '/riv/sim_wd/@fsoc__' + core.sname)
     common.remove_dir(cfg.fsoc_dir + "/" + core.sname)
     core.is_installed = False
 
@@ -63,24 +63,22 @@ def clean_ip(ip, no_infos=False):
     ip_str = f"{ip.vendor}/{ip.name}"
     ip_dir_name = f"{ip.vendor}__{ip.name}"
     
-    common.remove_dir(cfg.sim_output_dir + '/viv/cmp_wd/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/mdc/cmp_wd/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/vcs/cmp_wd/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/xcl/cmp_wd/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/qst/cmp_wd/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/riv/cmp_wd/' + ip_dir_name)
+    common.remove_dir(cfg.sim_output_dir + '/viv/sim_wd')
+    common.remove_dir(cfg.sim_output_dir + '/vcs/sim_wd')
+    common.remove_dir(cfg.sim_output_dir + '/xcl/sim_wd')
+    common.remove_dir(cfg.sim_output_dir + '/qst/sim_wd')
+    common.remove_dir(cfg.sim_output_dir + '/riv/sim_wd')
     
-    common.remove_dir(cfg.sim_output_dir + '/viv/elab_out/single_sim/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/mdc/elab_out/single_sim/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/vcs/elab_out/single_sim/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/xcl/elab_out/single_sim/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/qst/elab_out/single_sim/' + ip_dir_name)
+    common.remove_dir(cfg.sim_output_dir + '/viv/cmp_out/' + ip_dir_name)
+    common.remove_dir(cfg.sim_output_dir + '/vcs/cmp_out/' + ip_dir_name)
+    common.remove_dir(cfg.sim_output_dir + '/xcl/cmp_out/' + ip_dir_name)
+    common.remove_dir(cfg.sim_output_dir + '/qst/cmp_out/' + ip_dir_name)
     
-    common.remove_dir(cfg.sim_output_dir + '/viv/elab_out/regressions/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/mdc/elab_out/regressions/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/vcs/elab_out/regressions/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/xcl/elab_out/regressions/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/qst/elab_out/regressions/' + ip_dir_name)
+    #common.remove_dir(cfg.sim_output_dir + '/viv/regr_wd/' + ip_dir_name)
+    #common.remove_dir(cfg.sim_output_dir + '/mdc/regr_wd/' + ip_dir_name)
+    #common.remove_dir(cfg.sim_output_dir + '/vcs/regr_wd/' + ip_dir_name)
+    #common.remove_dir(cfg.sim_output_dir + '/xcl/regr_wd/' + ip_dir_name)
+    #common.remove_dir(cfg.sim_output_dir + '/qst/regr_wd/' + ip_dir_name)
     
     if ip.is_local:
         if no_infos:
@@ -92,12 +90,6 @@ def clean_ip(ip, no_infos=False):
             common.dbg(f"Deleting compiled code objects for external IP '{ip_str}'")
         else:
             common.info(f"Deleting compiled code objects for external IP '{ip_str}'")
-    common.remove_dir(cfg.sim_output_dir + '/viv/cmp_out/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/mdc/cmp_out/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/vcs/cmp_out/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/xcl/cmp_out/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/qst/cmp_out/' + ip_dir_name)
-    common.remove_dir(cfg.sim_output_dir + '/riv/cmp_out/' + ip_dir_name)
     ip.is_compiled  [common.simulators_enum.VIVADO ] = False
     ip.is_compiled  [common.simulators_enum.METRICS] = False
     ip.is_compiled  [common.simulators_enum.VCS    ] = False
