@@ -36,7 +36,7 @@ vivado_project_default_vlog_compilation_args = ["--relax"]
 vivado_project_default_vhdl_compilation_args = ["--relax"]
 
 vivado_default_gen_image_args  = ["--incr", "-sv", "-relax", "--O0", "-v 0", "-dup_entity_as_module"]
-metrics_default_gen_image_args = ["+acc+b", "-suppress MultiBlockWrite:ReadingOutputModport:UndefinedMacro:DupModuleDefn"]
+metrics_default_gen_image_args = ["+acc+b", "-suppress MultiBlockWrite:ReadingOutputModport", "-warn UndefinedMacro:DupModuleDefn"]
 vcs_default_gen_image_args     = ["-lca", "-sverilog"]
 xcelium_default_gen_image_args = []
 questa_default_gen_image_args  = ["-64", "-incrcomp"]
@@ -136,8 +136,43 @@ def gen_ip_image(ip, sim_job, fsoc_core_name, fsoc_core_flist_path):
     prep_ip_for_gen_image(ip, sim_job)
     
     if sim_job.simulator == common.simulators_enum.VIVADO:
-        pass
-        
+        timestamp_start = common.timestamp()
+        cmp_log_file_path = cmp_viv_master_flist(ip, ip.vendor, ip.name, flist_path, sim_job, ip.is_local)
+        if not sim_job.dry_run:
+            timestamp_end = common.timestamp()
+            errors = scan_cmp_log_file_for_errors(cmp_log_file_path, sim_job)
+        if len(errors):
+            common.error("Errors during compilation of IP '" + ip_str + "':")
+            for error in errors:
+                common.error("  " + error)
+            sim.kill_progress_bar()
+            common.fatal("Stopping due to compilation errors. Full log: " + cmp_log_file_path)
+        log_cmp_history_ip(ip, cmp_log_file_path, sim_job, timestamp_start, timestamp_end)
+        ip.is_compiled[sim_job.simulator] = True
+        defines = sim_job.cmp_args
+        if sim_job.is_regression:
+            ip_dir_name = f"{ip.vendor}__{ip.name}__{sim_job.regression_name}"
+            common.create_dir(cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name)
+            common.create_dir(cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name + "/" + sim_job.regression_timestamp)
+            elab_out =        cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name + "/" + sim_job.regression_timestamp
+        else:
+            ip_dir_name = f"{ip.vendor}__{ip.name}"
+            elab_out = cfg.sim_output_dir + "/" + sim_str + "/sim_wd"
+        common.create_dir(elab_out)
+        timestamp_start = common.timestamp()
+        elab_log_file_path = elaborate_viv_master_flist(ip, sim_job, elab_out)
+        if not sim_job.dry_run:
+            timestamp_end = common.timestamp()
+            errors = scan_elab_log_file_for_errors(elab_log_file_path, sim_job)
+            if len(errors):
+                common.error("Errors during elaboration of IP '" + ip_str + "':")
+                for error in errors:
+                    common.error("  " + error)
+                sim.kill_progress_bar()
+                common.fatal("Stopping due to elaboration errors. Full log: " + elab_log_file_path)
+            log_elab_history(ip, elab_log_file_path, sim_job, timestamp_start, timestamp_end)
+            ip.is_elaborated[sim_job.simulator] = True
+            return cmp_log_file_path, elab_log_file_path
     else:
         timestamp_start = common.timestamp()
         log_file_path = gen_image_flist(ip, ip.vendor, ip.name, flist_path, sim_job, ip.is_local)
@@ -149,7 +184,7 @@ def gen_ip_image(ip, sim_job, fsoc_core_name, fsoc_core_flist_path):
                 for error in errors:
                     common.error("  " + error)
                 sim.kill_progress_bar()
-                common.fatal("Stopping due to compilation/elaborationn errors. Full log: " + log_file_path)
+                common.fatal("Stopping due to compilation/elaboration errors. Full log: " + log_file_path)
             log_gen_image_history_ip(ip, log_file_path, sim_job, timestamp_start, timestamp_end)
             ip.is_compiled  [sim_job.simulator] = True
             ip.is_elaborated[sim_job.simulator] = True
@@ -447,6 +482,61 @@ def gen_image_flist(ip, vendor, name, flist_path, sim_job, local):
 
 
 
+
+def cmp_viv_master_flist(ip, vendor, name, flist_path, sim_job, is_local):
+    defines = sim_job.cmp_args
+    sim_str = common.get_simulator_short_name(sim_job.simulator)
+    arg_list = []
+    cmp_args_list = convert_compilation_args(sim_job)
+    deps_list     = convert_deps_to_args(deps, sim_job)
+    incdir_list   = get_incdir_list(deps, sim_job)
+    
+    #if licensed:
+    #    license_ip = cache.get_ip("datum", "uvml_mio_lic", True)
+    #    license_macros_file_path = license_ip.path + "/" + license_ip.src_path + "/uvml_mio_lic_macros.svh"
+    license_macros_file_path = ""
+    
+    ip_dir_name = f"{vendor}__{name}"
+    cmp_out_dir = cfg.sim_output_dir + "/" + sim_str + "/cmp_out/"
+    cmp_out = cmp_out_dir + ip_dir_name
+    
+    if sim_job.is_regression:
+        ip_dir_name = f"{sim_job.vendor}__{sim_job.ip}__{sim_job.regression_name}"
+        common.create_dir(cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name)
+        common.create_dir(cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name + "/" + sim_job.regression_timestamp)
+        sim_out = cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name + "/" + sim_job.regression_timestamp
+    else:
+        sim_out = cfg.sim_output_dir + "/" + sim_str + "/sim_wd"
+    
+    common.create_dir(cmp_out)
+    common.create_dir(sim_out)
+    
+    compilation_log_path = cfg.sim_dir + "/cmp/" + ip_dir_name + "." + sim_str + ".cmp.log"
+    compilation_command_file = f"{ip_dir_name}.{sim_str}.cmp.cmd.txt"
+    
+    arg_list += vivado_default_compilation_args
+    arg_list += incdir_list
+    arg_list.append(license_macros_file_path);
+    arg_list.append("-f " + flist_path)
+    arg_list += cmp_args_list
+    arg_list.append("-L uvm")
+    arg_list.append(f"--uvm_version {cfg.uvm_version}")
+    arg_list += deps_list
+    arg_list.append(f"--work {name}={cmp_out}")
+    arg_list.append("--log "  + compilation_log_path)
+    write_cmd_to_disk(sim_job, "xvlog", arg_list, compilation_command_file)
+    sim_job.bwrap_commands += launch_eda_bin(cfg.vivado_home + "/xvlog", arg_list, wd=sim_out, output=cfg.dbg, dry_run=sim_job.dry_run)
+    
+    return compilation_log_path
+
+
+
+
+def elaborate_viv_master_flist(ip, sim_job, elab_out):
+    pass
+
+
+
 def compile_flist(vendor, name, flist_path, deps, sim_job, local, licensed=True):
     defines = sim_job.cmp_args
     sim_str = common.get_simulator_short_name(sim_job.simulator)
@@ -960,7 +1050,7 @@ def set_uvm_version(sim_job):
     common.dbg(f"Setting UVM version: {cfg.uvm_version}")
     found_uvm_ver = False
     if sim_job.simulator == common.simulators_enum.METRICS:
-        config_path = cfg.project_dir + "/.mdc/config.yml"
+        config_path = cfg.project_dir + "/mdc_config.yml"
         try:
             with open(config_path, 'r') as cfg_file:
                 cfg_yaml = yaml.load(cfg_file, Loader=SafeLoader)
