@@ -138,12 +138,19 @@ def install_ip_and_deps(vendor, name, global_install, username="", password=""):
         cache.scan_and_load_ip_metadata()
         ip = cache.get_ip(vendor, name)
     
+    ip.delete_dependencies()
+    cache.scan_and_load_ip_metadata()
+    if vendor == "":
+        ip = cache.get_anon_ip(name)
+    else:
+        ip = cache.get_ip(vendor, name)
+    
     #deps_to_install = ip.get_ordered_install_deps()
     #common.info(f"Installing {len(deps_to_install)} dependencies")
     #install_ip_list(ip, deps_to_install, global_install, username, password)
     #cache.scan_and_load_ip_metadata()
     
-    deps_to_install = ip.get_deps_to_install()
+    deps_to_install = ip.get_ordered_install_deps()
     while len(deps_to_install) > 0:
         common.info(f"Installing {len(deps_to_install)} dependencies")
         install_ip_dep_list(ip, deps_to_install, global_install, username, password)
