@@ -296,6 +296,28 @@ class TestSuite:
         regr.suite = self
         common.dbg(f"Regression '{regr.name}' added to set '{self.name}'")
     
+    def get_gen_img_job(self):
+        sim_job = sim.SimulationJob(f"{self.ip.vendor}/{self.ip.name}")
+        sim_job.is_regression   = True
+        sim_job.regression_name = cfg.regression_name
+        sim_job.regression_timestamp = self.timestamp
+        sim_job.one_shot  = True
+        sim_job.compile   = True
+        sim_job.elaborate = True
+        sim_job.simulate  = False
+        sim_job.gui       = False
+        sim_job.simulator = self.simulator
+        sim_job.raw_args  = self.cmp_args
+        if cfg.regression_name in self.waves:
+            sim_job.waves = True
+        else:
+            sim_job.waves = False
+        if cfg.regression_name in self.cov:
+            sim_job.cov = True
+        else:
+            sim_job.cov = False
+        return sim_job
+    
     def get_cmp_job(self):
         sim_job = sim.SimulationJob(f"{self.ip.vendor}/{self.ip.name}")
         sim_job.is_regression   = True
@@ -494,7 +516,7 @@ def main(ip_str, regression, simulator, dry_mode):
     regression = test_suite.get_regression(cfg.cli_args.regr)
     regression.reduce()
     tests      = regression.get_tests()
-    prep_target_ip(ip, test_suite)
+    prep_target_ip(ip, test_suite, simulator)
     
     sim_job_list = []
     for test in tests:
@@ -523,24 +545,30 @@ def launch_sim_jobs(ip, test_suite, regression, sim_job_list, dry_mode):
     
     common.create_dir(cfg.regr_results_dir + "/" + cfg.target_ip_name + "_" + regression_name)
     common.create_dir(cfg.regr_results_dir + "/" + cfg.target_ip_name + "_" + regression_name + "/" + test_suite.timestamp)
-    sem = BoundedSemaphore(regression.max_jobs)
-    sem_cfg = BoundedSemaphore(1)
-    with tqdm(sim_job_list) as bar:
-    #with alive_bar(len(sim_job_list), bar = 'smooth') as bar:
-        for sim_job in sim_job_list:
-            common.dbg("Launching test threads")
-            thread = Thread(target=launch_test, args=(ip,test_suite,sim_job,dry_mode,))
-            thread.daemon = True
-            threads.append(thread)
-            thread.start()
-            time.sleep(10) # HACK!!!!! or else threads step on top of each other
-        timeout = Thread(target=timeout_process, args=(regression.max_duration,))
-        timeout.daemon = True
-        timeout.start()
-        common.dbg("Waiting for threads to end")
-        for thread in threads:
-            if thread.is_alive():
-                thread.join()
+    
+    for sim_job in sim_job_list:
+        # TEMPORARY UNTIL METRICS REGRESSION SYSTEM IS LIVE
+        if sim_job.simulator == common.simulators_enum.METRICS:
+            launch_test(ip,test_suite,sim_job,dry_mode)
+    else:
+        sem = BoundedSemaphore(regression.max_jobs)
+        sem_cfg = BoundedSemaphore(1)
+        with tqdm(sim_job_list) as bar:
+        #with alive_bar(len(sim_job_list), bar = 'smooth') as bar:
+            for sim_job in sim_job_list:
+                common.dbg("Launching test threads")
+                thread = Thread(target=launch_test, args=(ip,test_suite,sim_job,dry_mode,))
+                thread.daemon = True
+                threads.append(thread)
+                thread.start()
+                time.sleep(10) # HACK!!!!! or else threads step on top of each other
+            timeout = Thread(target=timeout_process, args=(regression.max_duration,))
+            timeout.daemon = True
+            timeout.start()
+            common.dbg("Waiting for threads to end")
+            for thread in threads:
+                if thread.is_alive():
+                    thread.join()
 
 
 def timeout_process(hours):
@@ -552,39 +580,54 @@ def timeout_process(hours):
     common.fatal(f"Regression timed out after {str(hours)} hour(s)")
 
 
-def prep_target_ip(ip, test_suite):
+def prep_target_ip(ip, test_suite, simulator):
     if cfg.test_suite_name != "":
         regression_name = cfg.test_suite_name + "_" + cfg.regression_name
     else:
         regression_name = cfg.regression_name
-    cmp_job  = test_suite.get_cmp_job ()
-    elab_job = test_suite.get_elab_job()
-    cmp_job .regression_name = regression_name
-    elab_job.regression_name = regression_name
-    sim.main(cmp_job )
-    sim.main(elab_job)
+    if simulator == "mdc":
+        gen_img_job = test_suite.get_gen_img_job()
+        gen_img_job.regression_name = regression_name
+        sim.main(gen_img_job)
+    else:
+        cmp_job  = test_suite.get_cmp_job ()
+        elab_job = test_suite.get_elab_job()
+        cmp_job .regression_name = regression_name
+        elab_job.regression_name = regression_name
+        sim.main(cmp_job )
+        sim.main(elab_job)
 
 
 def launch_test(ip, test_suite, sim_job, dry_mode):
     global sem_cfg
-    sem_cfg.acquire()
+    
+    if sim_job.simulator != common.simulators_enum.METRICS:
+        sem_cfg.acquire()
+    
     if cfg.test_suite_name != "":
         regression_name = cfg.test_suite_name + "_" + cfg.regression_name
     else:
         regression_name = cfg.regression_name
     sim_job.regression_name = regression_name
     plus_args = sim.convert_cli_args_to_plusargs(sim_job)
-    common.dbg("Waiting turn for simulating:\n" + str(sim_job))
-    sem_cfg.release()
-    wait_for_turn()
-    common.dbg("Done waiting. Starting thread for simulating:\n" + str(sim_job))
-    if dry_mode:
-        common.info(f"  dry-run: test='{sim_job.test}' seed='{str(sim_job.seed)}' args='{str(sim_job.args)}' waves='{str(sim_job.waves)}' cov='{str(sim_job.cov)}'")
+    
+    if sim_job.simulator == common.simulators_enum.METRICS:
+        # TEMPORARY UNTIL METRICS REGRESSION SYSTEM IS LIVE
+        common.info(f"Running: test='{sim_job.test}' seed='{str(sim_job.seed)}' args='{str(sim_job.sim_args)}' waves='{str(sim_job.waves)}' cov='{str(sim_job.cov)}' ...")
+        if not dry_mode:
+            eal.simulate(ip, sim_job)
     else:
-        eal.simulate(ip, sim_job)
-    common.dbg("Done simulating:\n" + str(sim_job))
-    bar.update(1)
-    done_with_turn()
+        common.dbg("Waiting turn for simulating:\n" + str(sim_job))
+        sem_cfg.release()
+        wait_for_turn()
+        common.dbg("Done waiting. Starting thread for simulating:\n" + str(sim_job))
+        if dry_mode:
+            common.info(f"  dry-run: test='{sim_job.test}' seed='{str(sim_job.seed)}' args='{str(sim_job.sim_args)}' waves='{str(sim_job.waves)}' cov='{str(sim_job.cov)}'")
+        else:
+            eal.simulate(ip, sim_job)
+        common.dbg("Done simulating:\n" + str(sim_job))
+        bar.update(1)
+        done_with_turn()
 
 
 def wait_for_turn():
