@@ -139,14 +139,7 @@ def main(sim_job):
                         global_install = False
                     else:
                         global_install = True
-                    common.info(f"Installing {len(deps_to_install)} dependencies ...")
-                    while len(deps_to_install) > 0:
-                        try:
-                            install.install_ip_dep_list(ip, deps_to_install, global_install)
-                        except Exception as e:
-                            common.fatal("Error during '" + ip_str + "' IP installation: " + str(e))
-                        cache.scan_and_load_ip_metadata()
-                        deps_to_install = ip.get_deps_to_install()
+                    install.install_ip_and_deps(ip.vendor, ip.name, global_install)
                 else:
                     common.fatal("Cannot continue without first installing '" + ip_str + "' IP dependencies.")
     
@@ -196,7 +189,8 @@ def one_step_sim(sim_job):
             if ip.dut.target_ip_model == None:
                 common.fatal(f"Did not resolve DUT dependency ('{ip.dut.vendor}/{ip.dut.target_ip}')!")
             if ip.dut.target_ip_model.sub_type == "vivado":
-                common.fatal("Vivado Project DUTs are not yet amenable to single-step compilation/elaboration flow.")
+                cmp_dut(ip, sim_job)
+                #common.fatal("Vivado Project DUTs are not yet amenable to single-step compilation/elaboration flow.")
     
     common.info(f"Compiling+Elaborating {ip_str} ...")
     eal.gen_ip_image(ip, sim_job, fsoc_core_name, flist_path)
